@@ -39,7 +39,6 @@
 #include <assert.h>
 #include <string.h> // for strdup()
 
-
 AccountNumberCheck *AccountNumberCheck_new()
 {
     return new AccountNumberCheck();
@@ -56,25 +55,22 @@ void AccountNumberCheck_delete(AccountNumberCheck *a)
 }
 
 AccountNumberCheck_Result
-AccountNumberCheck_check(const AccountNumberCheck *a, 
-			 const char *bankId, 
-			 const char *accountId)
+AccountNumberCheck_check(const AccountNumberCheck *a, const char *bankId, const char *accountId)
 {
     assert(a);
     return a->check(std::string(bankId ? bankId : ""),
-		    std::string(accountId ? accountId : ""));
+                    std::string(accountId ? accountId : ""));
 }
 
 const AccountNumberCheck_Record *
-AccountNumberCheck_findBank(const AccountNumberCheck *a, 
-			    const char *bankId)
+AccountNumberCheck_findBank(const AccountNumberCheck *a, const char *bankId)
 {
     assert(a);
     try {
-	return &(a->findBank(std::string(bankId ? bankId : "")));
-    } 
+        return &(a->findBank(std::string(bankId ? bankId : "")));
+    }
     catch (...) {
-	return NULL;
+        return NULL;
     }
 }
 
@@ -90,14 +86,13 @@ void AccountNumberCheck_createIndex(AccountNumberCheck *a)
     a->createIndex();
 }
 
-
 void
 AccountNumberCheck_Record_delete(AccountNumberCheck_Record *a)
 {
     delete (a);
 }
 
-unsigned long 
+unsigned long
 AccountNumberCheck_Record_bankId(const AccountNumberCheck_Record *a)
 {
     assert(a);
@@ -125,18 +120,17 @@ AccountNumberCheck_Record_copy(const AccountNumberCheck_Record *a)
     return new AccountNumberCheck_Record(*a);
 }
 
-const char* AccountNumberCheck_stringEncoding()
+const char *AccountNumberCheck_stringEncoding()
 {
-  return AccountNumberCheck::stringEncoding();
+    return AccountNumberCheck::stringEncoding();
 }
 
-const char* AccountNumberCheck_libraryVersion()
+const char *AccountNumberCheck_libraryVersion()
 {
-  return AccountNumberCheck::libraryVersion();
+    return AccountNumberCheck::libraryVersion();
 }
 
-char* AccountNumberCheck_bankdata_dir()
+char *AccountNumberCheck_bankdata_dir()
 {
-  return strdup(AccountNumberCheck::bankdata_dir().c_str());
+    return strdup(AccountNumberCheck::bankdata_dir().c_str());
 }
-
